function varargout = gyakorlat_5(varargin)
% GYAKORLAT_5 MATLAB code for gyakorlat_5.fig
%      GYAKORLAT_5, by itself, creates a new GYAKORLAT_5 or raises the existing
%      singleton*.
%
%      H = GYAKORLAT_5 returns the handle to a new GYAKORLAT_5 or the handle to
%      the existing singleton*.
%
%      GYAKORLAT_5('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GYAKORLAT_5.M with the given input arguments.
%
%      GYAKORLAT_5('Property','Value',...) creates a new GYAKORLAT_5 or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before gyakorlat_5_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to gyakorlat_5_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help gyakorlat_5

% Last Modified by GUIDE v2.5 14-Oct-2014 22:12:04

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gyakorlat_5_OpeningFcn, ...
                   'gui_OutputFcn',  @gyakorlat_5_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before gyakorlat_5 is made visible.
function gyakorlat_5_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to gyakorlat_5 (see VARARGIN)

% Choose default command line output for gyakorlat_5

handles.output = hObject;
ah = axes('unit','normalized','position',[0 0 1 1]);
bg = imread('Lorenz.png');
imagesc(bg);
set(ah,'handlevisibility','off','visible','off')
uistack(ah, 'bottom');

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes gyakorlat_5 wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = gyakorlat_5_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
%plot(handles.axes1,imshow('frodo.jpg'));
%figure
%ax(1) = subplot(1,2,1);
axes(handles.axes1);
kep = imread('frodo.jpg');
imshow(kep);

function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
implay('pendulum.mp4');
